
package com.zerog.ia.customcode.installpanels;

import java.awt.*;
import java.net.*;

import com.zerog.ia.api.pub.*;

import com.zerog.ia.customcode.util.miscutils.*;

public class DisplayImage extends CustomCodePanel
{
	//
	// Constants
	//
	private static final String TITLE_VAR_NAME = "$DisplayImage_Title$";
	private static final String IMAGESOURCE_VAR_NAME = "$DisplayImage_ImageSourcePath$";
	private static final String SCROLLPOLICY_VAR_NAME =	"$DisplayImage_ScrollPolicy$";

	private static final String SCROLLBARS_NEVER_VALUE = "SCROLLBARS_NEVER";
	private static final String SCROLLBARS_ALWAYS_VALUE = "SCROLLBARS_ALWAYS";

	private ScrollPane scrollPane;
	private ImageComponent imageComponent;

	private String title;

	//
	// Note: This flag is used to ensure the UI elements are only set up once.
	//       This is needed because of the addition of back buttons in all
	//       panels (IA 3.5 and later).
	//
	boolean inited = false;

	/**
	 *	This method implements </tt>CustomCodePanel.setupUI()</tt>.  Please read
	 *	the JavaDoc for that method before reading through the source.
	 *
	 *	@see com.zerog.ia.api.pub.CustomCodePanel#setupUI
	 *	@see com.zerog.ia.api.pub.CustomCodePanelProxy
	 */
	public boolean setupUI( CustomCodePanelProxy ccpp )
	{
		//
		// Get input from InstallAnywhere Variables.  The resolved contents of
		// the IA Variables are retieved into the Strings (substitute always
		// returns string values (getVariable() returns objects).
		//
		title = ccpp.substitute( TITLE_VAR_NAME );
		String scrollPolicy = ccpp.substitute( SCROLLPOLICY_VAR_NAME );
		String imageSource = ccpp.substitute( IMAGESOURCE_VAR_NAME );

		//
		// substitute() will return an empty string for any InstallAnywhere
		// Variable that hasn't been assigned yet
		//

		//
		// Now, determine if all the parameters are valid.  First check that
		// there are parameters set for title and image source, then that
		// the image can be loaded.  At that point we can return true,
		// telling the installer that we'd like to be shown.  If anything
		// goes wrong, we return false, and we won't be shown.
		//
		if ( title.equals("") )
		{
			System.err.println("DisplayImage: " + TITLE_VAR_NAME + " hasn't been set.");
			return false;
		}

		if ( imageSource.equals("") )
		{
			System.err.println("DisplayImage: " + IMAGESOURCE_VAR_NAME + " hasn't been set.");
			return false;
		}

		//
		// Now set up the GUI and optionally turn on scrollbars
		//
		// Note: Because of changes to the way the seupUI() method is
		//       called on Custom Code Panels in 3.5 and later, We
		//       have wrapped the GUI setup code with a non-static flag
		//       so that we only set up the UI once (thus avoiding
		//       unexpected behavior such as duplicate UI components).
		//       If you have existing custom code from 3.0.x Enterprise,
		//       you should make sure to implement this type of check.
		//
		// Note: Also notice that only the setup of the UI components are
		//       are controlled by this flag.  By not wrapping the other
		//       code in this method, the expected behavior of this custom
		//       code panel action is not lost.
		//
		if(!inited)
		{
			//
			// set the flag to true.
			//
			inited = true;

			this.setLayout( new BorderLayout() );

			if (   scrollPolicy.equals("")
				|| scrollPolicy.equals( SCROLLBARS_NEVER_VALUE ) )
			{
				scrollPane = new ScrollPane( ScrollPane.SCROLLBARS_NEVER );
			}
			else if ( scrollPolicy.equals( SCROLLBARS_ALWAYS_VALUE ) )
			{
				scrollPane = new ScrollPane( ScrollPane.SCROLLBARS_ALWAYS );
			}
			else
			{
				scrollPane = new ScrollPane( ScrollPane.SCROLLBARS_AS_NEEDED );
			}

			//
			// Create the image component.  the image will be set below.
			//
			imageComponent = new ImageComponent();
			scrollPane.add(imageComponent);

			this.add( BorderLayout.CENTER, scrollPane );
		}

		//
		// Ok, try loading the image
		//
		URL imageSourceURL = ccpp.getResource( imageSource );
		Image img = ImageUtils.loadImageFromURL( imageSourceURL, imageComponent );

		if ( img == null )
		{
			System.err.println("DisplayImage: " + imageSourceURL + " could not be loaded.");
			return false;
		}

		imageComponent.setImage(img);

		return true;
	}

	/**
	 *	The GUI has already been set up, so there is nothing left to
	 *	do when we're displayed.
	 *
	 *	@see com.zerog.ia.api.pub.CustomCodePanel#panelIsDisplayed
	 */
	public void panelIsDisplayed()
	{
	}

	/**
	 *	Since there's no reason to prevent the user from continuing,
	 *	always return true.
	 *
	 *	@see com.zerog.ia.api.pub.CustomCodePanel#okToContinue
	 */
	public boolean okToContinue()
	{
		return true;
	}

	/**
	 *	Return the title we'd like to see displayed on the top of the Installer
	 *	while this panel is displayed.  The <tt>title</tt> member is set in
	 *	<tt>setupUI</tt>.
	 *
	 *	@see #setupUI
	 *	@see com.zerog.ia.api.pub.CustomCodePanel#getTitle
	 */
	public String getTitle()
	{
		return title;
	}

/*
	Test method

	public static void main( String[] args )
	{
		Frame f = new Frame( "Test Frame" );
		f.setLayout( new BorderLayout() );

		DisplayImage ccp = new DisplayImage();
		ccp.setLayout( new BorderLayout() );

		ImageComponent ic = new ImageComponent();
		URL source = null;
		try {
			source = new URL( args[0] );
		} catch ( IOException ioe ) {
			ioe.printStackTrace();
		}
		Image img = ImageUtils.loadImageFromURL( source, ic );
		ic.setImage( img );
		ccp.add( BorderLayout.CENTER, ic );

		f.add( BorderLayout.CENTER, ccp );
		f.pack();
		f.show();
	}
*/
}
